==> haskell-snap-server-1.1.1.1-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.1.1
id: snap-server-1.1.1.1-FIOY1A5HCU3Dhq7GqpHtUz
key: snap-server-1.1.1.1-FIOY1A5HCU3Dhq7GqpHtUz
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: a9c15caec2714ab308ca16b8dd2abd85
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.6.4/site-local/snap-server-1.1.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/snap-server-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/snap-server-1.1.1.1
hs-libraries: HSsnap-server-1.1.1.1-FIOY1A5HCU3Dhq7GqpHtUz
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj containers-0.6.0.1
    filepath-1.4.2.1 io-streams-1.5.1.0-CUewG0JMedi8iIWXIBBM0n
    io-streams-haproxy-1.0.1.0-Ehu1pV7rBQGD36Xxnh21CH
    lifted-base-0.2.3.12-8heWM5OQv9z9kSVVPUcBPl mtl-2.2.2
    network-2.8.0.0-79Coriq35AYDs1MobOTL51
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    snap-core-1.0.4.0-9cvP1SX4Kqi1d5iTkaeLO text-1.2.3.1 time-1.8.0.2
    unix-2.7.2.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.1.1-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.1.1
id: snap-server-1.1.1.1-JVMmNMlb3XC5szwIRpQjgs
key: snap-server-1.1.1.1-JVMmNMlb3XC5szwIRpQjgs
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: 02c2a1b47811bda5243bdfce0f77b5e5
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/snap-server-1.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/snap-server-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/snap-server-1.1.1.1
hs-libraries: HSsnap-server-1.1.1.1-JVMmNMlb3XC5szwIRpQjgs
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj containers-0.6.0.1
    filepath-1.4.2.1 io-streams-1.5.1.0-6CabpVTlzCiI6sPglA7ixD
    io-streams-haproxy-1.0.1.0-KCBrNs3MyPIBDD7XRhRoEg
    lifted-base-0.2.3.12-8heWM5OQv9z9kSVVPUcBPl mtl-2.2.2
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    snap-core-1.0.4.0-BPiNZGHzX5tJ7GTttMU9EK text-1.2.3.1 time-1.8.0.2
    unix-2.7.2.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
